<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Voltar à interface gráfica completa',
	'access_mode_texte' => 'Exibir a interface textual simplificada',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modificar este artigo',
	'admin_modifier_auteur' => 'Modificar este autor',
	'admin_modifier_breve' => 'Modificar esta notícia',
	'admin_modifier_mot' => 'Modificar esta palavra-chave',
	'admin_modifier_rubrique' => 'Modificar esta rubrica',
	'admin_recalculer' => 'Recompor esta página',
	'afficher_calendrier' => 'Exibir o calendário',
	'afficher_trad' => 'exibir as traduções',
	'alerte_maj_impossible' => '<b>Alerta !</b> A actualização da base de dados SQL para a versão @version@ é impossível, talvez por causa de um problema de permissão de modificação na base de dados. Por favor contacte o seu serviço de hospedagem.',
	'alerte_modif_info_concourante' => 'ATTENÇÃO : Esta informação já foi modificada noutro menu. O valor actual é :',
	'analyse_xml' => 'Análise XML',
	'annuler' => 'Cancelar',
	'antispam_champ_vide' => 'Por favor deixe este campo vazio :',
	'articles_recents' => 'Artigos mais recentes',
	'avis_archive_incorrect' => 'o ficheiro arquivo não é um ficheiro SPIP',
	'avis_archive_invalide' => 'o ficheiro arquivo não é válido ',
	'avis_attention' => ' ATENÇÂO!',
	'avis_champ_incorrect_type_objet' => 'Nome de campo incorrecto @name@ para objecto de tipo @type@',
	'avis_colonne_inexistante' => 'A coluna  @col@ não existe',
	'avis_erreur' => 'Erro: ver mais abaixo',
	'avis_erreur_connexion' => 'Erro de ligação ',
	'avis_erreur_cookie' => 'problema de cookie',
	'avis_erreur_fonction_contexte' => 'Erro de programação. Não se pode chamar esta função neste contexto.',
	'avis_erreur_mysql' => 'Erro SQL',
	'avis_erreur_sauvegarde' => 'Erro na cópia de segurança  (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problema de acesso à área privada',

	// B
	'barre_a_accent_grave' => 'Inserir um A maiúsculo com acento grave',
	'barre_aide' => 'Utilize as abreviaturas tipográficas para enriquecer a sua paginação.',
	'barre_e_accent_aigu' => 'Inserir um E maiúsculo com acento agudo ',
	'barre_eo' => 'Inserir um E no O',
	'barre_eo_maj' => 'Inserir um E no O maiúsculo',
	'barre_euro' => 'Inserir o símbolo €',
	'barre_gras' => '  Escrever em {{negro}}',
	'barre_guillemets' => 'Colocar entre "aspas" ',
	'barre_guillemets_simples' => 'Colocar entre ’aspas simples’',
	'barre_intertitre' => 'Transfomar em  {{{intertítulo}}} ',
	'barre_italic' => 'Pôr em itálico ',
	'barre_lien' => 'Transformar em [ligação hipertexto->http://...]',
	'barre_lien_input' => 'Por favor indique o endereço da sua ligação (pode indicar um endereço Web sob a forma  http://www.monsite/com ou simplesmente indicar o número de um artigo deste sítio.) ',
	'barre_note' => 'Transformar em  [[Nota de rodapé ]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_quote' => '<quote>Citar uma  mensagem</quote>',
	'bouton_changer' => 'Modificar',
	'bouton_chercher' => 'Procurar',
	'bouton_choisir' => 'Seleccionar',
	'bouton_deplacer' => 'Mover',
	'bouton_download' => 'Download',
	'bouton_enregistrer' => 'Guardar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar a caixa de correio interno',
	'bouton_radio_envoi_annonces' => 'Enviar os anúncios editoriais',
	'bouton_radio_non_envoi_annonces' => 'Não enviar anúncios',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Não enviar a lista das novidades',
	'bouton_recharger_page' => 'recarregar esta página',
	'bouton_telecharger' => 'Carregar',
	'bouton_upload' => 'Carregar',
	'bouton_valider' => 'Submeter',

	// C
	'cal_apresmidi' => 'tarde',
	'cal_jour_entier' => 'dia todo',
	'cal_matin' => 'manhã',
	'cal_par_jour' => 'calendário por dia',
	'cal_par_mois' => 'calendário por mês',
	'cal_par_semaine' => 'calendário por semana',
	'choix_couleur_interface' => 'cor',
	'choix_interface' => 'escolha da interface',
	'colonne' => 'Coluna',
	'confirm_changer_statut' => 'Atenção, solicitou a alteração do estatuto deste elemento. Deseja continuar?',
	'correcte' => 'correcto',

	// D
	'date_aujourdhui' => 'hoje',
	'date_avant_jc' => 'a. J.C.',
	'date_dans' => 'entre @delai@',
	'date_de_mois_1' => '@j@ de @nommois@',
	'date_de_mois_10' => '@j@ de @nommois@',
	'date_de_mois_11' => '@j@ de @nommois@',
	'date_de_mois_12' => '@j@ de @nommois@',
	'date_de_mois_2' => '@j@ de @nommois@',
	'date_de_mois_3' => '@j@ de @nommois@',
	'date_de_mois_4' => '@j@ de @nommois@',
	'date_de_mois_5' => '@j@ de @nommois@',
	'date_de_mois_6' => '@j@ de @nommois@',
	'date_de_mois_7' => '@j@ de @nommois@',
	'date_de_mois_8' => '@j@ de @nommois@',
	'date_de_mois_9' => '@j@ de @nommois@',
	'date_demain' => 'amanhã',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@:@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de @heure_debut@ a @heure_fin@', # MODIF
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ de @heure_debut@@dtabbr@ a @dtstart@@heure_fin@@dtend@', # MODIF
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => ' @nomjour@ @date@',
	'date_fmt_periode' => 'De @date_debut@ a @date_fin@',
	'date_fmt_periode_abbr' => 'De @dtart@@date_debut@@dtabbr@ a @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'De',
	'date_fmt_periode_to' => 'a',
	'date_heures' => 'horas',
	'date_hier' => 'ontem',
	'date_il_y_a' => 'há @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'domingo',
	'date_jour_1_abbr' => 'Dom.',
	'date_jour_1_initiale' => 'D.',
	'date_jour_2' => 'segunda-feira',
	'date_jour_2_abbr' => 'Seg.',
	'date_jour_2_initiale' => 'S.',
	'date_jour_3' => 'terça-feira',
	'date_jour_3_abbr' => 'Ter.',
	'date_jour_3_initiale' => 'T.',
	'date_jour_4' => 'quarta-feira',
	'date_jour_4_abbr' => 'Qua.',
	'date_jour_4_initiale' => 'Q.',
	'date_jour_5' => 'quinta-feira',
	'date_jour_5_abbr' => 'Qui.',
	'date_jour_5_initiale' => 'Q.',
	'date_jour_6' => 'sexta-feira',
	'date_jour_6_abbr' => 'Sex.',
	'date_jour_6_initiale' => 'S.',
	'date_jour_7' => 'sábado',
	'date_jour_7_abbr' => 'Sab.',
	'date_jour_7_initiale' => 'S.',
	'date_jours' => 'dias',
	'date_minutes' => 'minutos',
	'date_mois' => 'meses',
	'date_mois_1' => 'Janeiro',
	'date_mois_10' => 'Outubro',
	'date_mois_10_abbr' => 'Out.',
	'date_mois_11' => 'Novembro',
	'date_mois_11_abbr' => 'Nov.',
	'date_mois_12' => 'Dezembro',
	'date_mois_12_abbr' => 'Dez.',
	'date_mois_1_abbr' => 'Jan.',
	'date_mois_2' => 'Fevereiro',
	'date_mois_2_abbr' => 'Feb.',
	'date_mois_3' => 'Março',
	'date_mois_3_abbr' => 'Mar',
	'date_mois_4' => 'Abril',
	'date_mois_4_abbr' => 'Abr.',
	'date_mois_5' => 'Maio',
	'date_mois_5_abbr' => 'Mai',
	'date_mois_6' => 'Junho',
	'date_mois_6_abbr' => 'Jun',
	'date_mois_7' => 'Julho',
	'date_mois_7_abbr' => 'Jul',
	'date_mois_8' => 'Agosto',
	'date_mois_8_abbr' => 'Ago',
	'date_mois_9' => 'Setembro',
	'date_mois_9_abbr' => 'Set',
	'date_saison_1' => 'inverno',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'verão',
	'date_saison_4' => 'outono',
	'date_secondes' => 'segundos',
	'date_semaines' => 'semanas',
	'date_un_mois' => 'mês',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minuto',
	'date_une_seconde' => 'segundo',
	'date_une_semaine' => 'semana',
	'dirs_commencer' => 'a fim de começar realmente a instalação',
	'dirs_preliminaire' => 'Preliminar : <b>Configurar os direitos de acesso</b>',
	'dirs_probleme_droits' => 'Problema de direitos de acesso',
	'dirs_repertoires_absents' => '<b>Os seguintes directórios não foram encontrados : <ul>@bad_dirs@.</ul> </b>
  <p>É provável que resulte de um problema de má colocação de maiúsculas ou minúsculas.
  Verifique que as minúsculas e maiúsculas destes directórios concordam com o que está exibido
 acima; se não for o caso, renomeie os repertórios com o seu software FTP de modo a corrigir o erro.
  <p>Terminada esta operação, poderá</p>',
	'dirs_repertoires_suivants' => '<b>Os seguintes directórios não estão acessíveis para escrita: <ul>@bad_dirs@.</ul> </b>
  <p>Para corrigir, utilize o seu programa de FTP para configurar os direitos de acesso de cada um
  destes directórios. O procedimento está explicado em detalhe no manual de instalação.
  <p>Uma vez efectuada esta alteração, poderá',
	'double_occurrence' => 'Dupla ocorrência de @balise@',

	// E
	'en_cours' => 'em curso',
	'envoi_via_le_site' => 'Envio pelo sítio',
	'erreur' => 'Erro',
	'erreur_balise_non_fermee' => 'última tag não fechada :',
	'erreur_technique_ajaxform' => 'Ooops. Uum erro inesperado impediu o formulário de ser enviado. Por favor tente novamente.',
	'erreur_technique_enregistrement_champs' => 'Um erro técnico impediu o registo correcto do campo @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Um erro técnico impediu o registo.',
	'erreur_texte' => 'erro(s)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'Ficheiro @fichier@ não localizado', # MODIF
	'form_auteur_confirmation' => 'Confirme o seu endereço e-mail',
	'form_auteur_email_modifie' => 'O seu endereço e-mail foi alterado.',
	'form_auteur_envoi_mail_confirmation' => 'Um e-mail de confirmação foi enviado para @email@. Para validar o seu endereço de e-mail, deve abrir o endereço Web mencionado na mensagem.',
	'form_auteur_mail_confirmation' => 'Olá,

Pediu para alterar o seu endereço e-mail. Para confirmar o seu novo endereço, precisa de se conectar ao endereço abaixo (caso contrário, o seu pedido será ignorado) :

    @url@
',
	'form_deja_inscrit' => 'Já está inscrito.',
	'form_email_non_valide' => 'O seu endereço email não é válido',
	'form_forum_access_refuse' => 'Você já não tem acesso a este sítio',
	'form_forum_bonjour' => 'Bom dia @nom@,',
	'form_forum_confirmer_email' => 'Para confirmar o seu endereço e-maill, abra esta ligação : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Este endereço e-mail já está registado,pode portanto utilizar a sua palavra-passe habitual',
	'form_forum_identifiant_mail' => 'O seu novo identificador acabou de lhe ser enviado por email.',
	'form_forum_identifiants' => 'Identificadores pessoais',
	'form_forum_indiquer_nom_email' => 'Indicar aqui o seu nome e o seu endereço email. O seu identificador pessoal ser-lhe-á enviado rapidamente por correio electrónico.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(esta é uma mensagem automática)',
	'form_forum_pass' => 'palavra-passe',
	'form_forum_probleme_mail' => 'Problema de mail :o identificador não pôde ser enviado',
	'form_forum_voici1' => 'Aqui estão os seus dados para poder aceder ao sítio Internet do  "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Eis os seus identificadores para propor artigos no
 sítio "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Por favor indique o seu endereço email.',
	'form_indiquer_nom' => 'Por favor indique o seu nome.',
	'form_indiquer_nom_site' => 'Por favor indique o nome do seu sítio.',
	'form_pet_deja_enregistre' => 'Este sítio já está registado',
	'form_pet_signature_pasprise' => 'A sua assinatura não está tomada em conta.',
	'form_prop_confirmer_envoi' => 'Confirmar o envio',
	'form_prop_description' => 'Descrição/comentário',
	'form_prop_enregistre' => 'A sua proposta foi registada. Aparecerá online após a validação pelos responsáveis deste sítio.',
	'form_prop_envoyer' => 'Enviar uma mensagem',
	'form_prop_indiquer_email' => 'Por favor indique um endereço email válido',
	'form_prop_indiquer_nom_site' => 'Por favor indique o nome do sítio.',
	'form_prop_indiquer_sujet' => 'Por favor indique um tema',
	'form_prop_message_envoye' => 'Mensagem enviada',
	'form_prop_non_enregistre' => 'A sua proposta não foi registada.',
	'form_prop_sujet' => 'Tema',
	'form_prop_url_site' => 'Endereço (URL) do sítio',
	'forum_non_inscrit' => 'Não está inscrito, ou o endereço ou a palavra-passe estão errados.',
	'forum_par_auteur' => 'por @auteur@',
	'forum_titre_erreur' => 'Erro...',

	// I
	'ical_texte_rss_articles' => 'O ficheiro «backend» dos artigos deste sítio encontra-se neste endereço:',
	'ical_texte_rss_articles2' => 'Pode igualmente obter os ficheiros «backend» para os artigos de cada rubrica do sítio:',
	'ical_texte_rss_breves' => 'Existe também um ficheiro contendo notícias do sítio. Especificando um número de rubrica, obterá unicamente as notícias dessa rubrica.',
	'icone_a_suivre' => 'Continua',
	'icone_admin_site' => 'Administração do sítio',
	'icone_agenda' => 'Agenda e correio',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Artigos',
	'icone_auteurs' => 'Autores',
	'icone_brouteur' => 'Navegação rápida',
	'icone_configuration_site' => 'Configuração',
	'icone_configurer_site' => 'Configurar o seu sítio',
	'icone_creer_nouvel_auteur' => 'Criar um novo autor',
	'icone_creer_rubrique' => 'Criar uma rubrica',
	'icone_creer_sous_rubrique' => 'Criar uma sub-rubrica',
	'icone_deconnecter' => 'Sair',
	'icone_discussions' => 'Discussões',
	'icone_doc_rubrique' => 'Documentos das rubricas',
	'icone_ecrire_article' => 'Escrever um novo artigo',
	'icone_edition_site' => 'Edição',
	'icone_gestion_langues' => 'Opções de idiomas',
	'icone_informations_personnelles' => 'Informações pessoais',
	'icone_interface_complet' => 'interface completa',
	'icone_interface_simple' => 'Interface simplificada',
	'icone_maintenance_site' => 'Manutenção do sítio',
	'icone_messagerie_personnelle' => 'Mensagens privadas',
	'icone_repartition_debut' => 'Exibir a distribuição desde o início',
	'icone_rubriques' => 'Rubricas',
	'icone_sauver_site' => 'Cópia de segurança do sítio',
	'icone_site_entier' => 'Todo o sítio',
	'icone_sites_references' => 'Sítios referenciados',
	'icone_statistiques' => 'Estatísticas do sítio',
	'icone_suivi_activite' => 'Acompanhar a actividade do sítio',
	'icone_suivi_actualite' => 'Evolução do sítio',
	'icone_suivi_pettions' => 'Seguir/gerir os abaixo-assinados',
	'icone_suivi_revisions' => 'Modificações dos artigos',
	'icone_supprimer_document' => 'Suprimir este documento',
	'icone_supprimer_image' => 'Suprimir esta imagem',
	'icone_tous_articles' => 'Todos os seus artigos',
	'icone_tous_auteur' => 'Todos os autores',
	'icone_tous_visiteur' => 'Todos os visitantes',
	'icone_visiter_site' => 'Visitar o sítio público',
	'icone_voir_en_ligne' => 'Ver online',
	'img_indisponible' => 'imagem indisponível',
	'impossible' => 'impossível',
	'info_a_suivre' => 'A SEGUIR »',
	'info_acces_interdit' => 'Acesso proibido',
	'info_acces_refuse' => 'Acesso recusado',
	'info_action' => 'Acção : @action@',
	'info_administrer_rubriques' => 'Pode administrar esta rubrica e as suas sub-rubricas',
	'info_adresse_non_indiquee' => 'Não indicou endereço a testar !',
	'info_aide' => 'AJUDA',
	'info_ajouter_mot' => 'Acrescentar esta palavra',
	'info_annonce' => 'ANÚNCIO',
	'info_annonces_generales' => 'Anúncios gerais :',
	'info_article_propose' => 'Artigo proposto',
	'info_article_publie' => 'Artigo publicado',
	'info_article_redaction' => 'Artigo em curso de redacção',
	'info_article_refuse' => 'Artigo recusado',
	'info_article_supprime' => 'Artigo suprimido',
	'info_articles' => 'Artigos',
	'info_articles_a_valider' => 'Os artigos a validar',
	'info_articles_nb' => '@nb@ artigos',
	'info_articles_proposes' => 'Artigos propostos',
	'info_articles_un' => '1 artigo',
	'info_auteurs_nombre' => 'autor(es) :',
	'info_authentification_ftp' => 'Autenticação (por FTP)',
	'info_breves_2' => 'notícias',
	'info_breves_nb' => '@nb@ notícias',
	'info_breves_un' => '1 notícia',
	'info_connexion_refusee' => 'Ligação recusada',
	'info_contact_developpeur' => 'Por favor contacte um programador',
	'info_contenance' => 'Este sítio contém:',
	'info_contribution' => 'contribuições de fórum',
	'info_copyright' => '@spip@ é um software livre distribuído @lien_gpl@.',
	'info_copyright_doc' => 'Para mais informações, visite o sítio <a href="@spipnet@">@spipnet_affiche@</a',
	'info_copyright_gpl' => 'sob licença GPL',
	'info_cours_edition' => 'Os seus artigos em curso de redacção', # MODIF
	'info_creer_repertoire' => 'Por favor crie um ficheiro ou um directório chamado :',
	'info_creer_repertoire_2' => 'dentro do sub-directório <b>@repertoire@</b>, depois :',
	'info_creer_vignette' => 'criação automática de miniatura',
	'info_creerdansrubrique_non_autorise' => 'Não tem direitos suficientes para criar conteúdo nesta rubrica.',
	'info_deplier' => 'Desenvolver',
	'info_descriptif_nombre' => 'descritivo(s) :',
	'info_description' => 'Descrição :',
	'info_description_2' => 'Descrição :',
	'info_dimension' => 'Dimensões :',
	'info_documents_nb' => '@nb@ documentos',
	'info_documents_un' => '1 documento',
	'info_ecire_message_prive' => 'Escrever uma mensagem privada',
	'info_email_invalide' => 'Endereço email inválido.',
	'info_en_cours_validation' => 'Os seus artigos em curso de redação',
	'info_en_ligne' => 'Actualmente online:',
	'info_envoyer_message_prive' => 'Enviar uma mensagem privada a este autor',
	'info_erreur_requete' => 'Erro no pedido :',
	'info_erreur_squelette2' => 'Modelo <b>@fichier@</b> não disponível...',
	'info_erreur_systeme' => 'Erro de Sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'O disco rígido poderá estar cheio, ou a base de dados danificada.<br />
<span style="color:red;">Tente <a href=\'@script@\'>reparar a base de dados </a>, ou contacte o seu fornecedor de internet.</span>',
	'info_fini' => 'Terminou !',
	'info_format_image' => 'Formatos de imagens que podem ser utilizadas para criar vinhetas : @gd_formats@.',
	'info_format_non_defini' => 'formato não definido',
	'info_grand_ecran' => 'Ecrã total',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Como criar miniaturas',
	'info_impossible_lire_page' => '<b>Erro !</b> Impossível ler a página<tt><html>@test_proxy@</html></tt> através do proxy <tt>',
	'info_installation_systeme_publication' => 'Instalação do sistema de publicação',
	'info_installer_documents' => 'Pode instalar automaticamente todos os documentos contidos na pasta @upload@.',
	'info_installer_ftp' => 'Como administrador, pode instalar (por FTP) ficheiros na pasta @upload@ para depois seleccioná-los directamente aqui.',
	'info_installer_images' => 'Pode instalar imagens nos formatos JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Instalar imagens na pasta @upload@ para poder seleccioná-los aqui.',
	'info_interface_complete' => 'Interface completa',
	'info_interface_simple' => 'Interface simplificada',
	'info_joindre_document_article' => 'Pode juntar a este artigo documentos de tipo',
	'info_joindre_document_rubrique' => 'Pode acrescentar a esta rubrica documentos de tipo',
	'info_joindre_documents_article' => 'Pode juntar ao seu artigo documentos de tipo :',
	'info_l_article' => 'o artigo',
	'info_la_breve' => 'a notícia',
	'info_la_rubrique' => 'a rubrica',
	'info_langue_principale' => 'Idioma principal do sítio',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'por @les_auteurs@',
	'info_logo_format_interdit' => 'Apenas os ícones nos formatos @formats@ estão autorizados.',
	'info_logo_max_poids' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_mail_fournisseur' => 'você@seucorreio.com',
	'info_message_2' => 'MENSAGEM',
	'info_message_supprime' => 'MENSAGEM ELIMINADA',
	'info_messages_nb' => '@nb@ mensagens',
	'info_messages_un' => '1 mensagem',
	'info_mise_en_ligne' => 'Data de colocação online :',
	'info_modification_parametres_securite' => 'modificação dos parâmetros de segurança',
	'info_mois_courant' => 'Durante o mês :',
	'info_mot_cle_ajoute' => 'A seguinte palavra-chave foi acrescentada a',
	'info_multi_herit' => 'Idioma por defeito',
	'info_multi_langues_soulignees' => 'Os <u>idiomas sublinhadas</u> beneficiam de uma tradução de todos os textos da interface. Se seleccionar esses idiomas, muitos elementos do sítio público (datas, formulários) serão automaticamente traduzidos. Para os idiomas não sublinhadas, esses elementos aparecerão no idioma principal do sítio.',
	'info_multilinguisme' => 'Multilinguismo',
	'info_nom_non_utilisateurs_connectes' => 'O seu nome não aparece na lista dos utilizadores ligados.',
	'info_nom_utilisateurs_connectes' => 'O seu nome aparece na lista dos utilizadores ligados.',
	'info_nombre_en_ligne' => 'Actualmente online :',
	'info_non_resultat' => 'Nenhum resultado para "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Não utiliza o correio interno deste sítio.',
	'info_nouveau_message' => 'TEM UMA NOVA MENSAGEM',
	'info_nouveaux_messages' => 'TEM @total_messages@ NOVAS MENSAGENS',
	'info_numero_abbreviation' => '<N° >',
	'info_obligatoire' => 'Esta informação é obrigatória',
	'info_pense_bete' => 'MEMORANDO',
	'info_petit_ecran' => 'Ecrã Pequeno',
	'info_petition_close' => 'Petição encerrada',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Muitas palavras-chave encontradas para "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portfolio automático :',
	'info_premier_resultat' => '[@debut_limit@ primeiros resultados em @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primeiros resultados em @total@]',
	'info_propose_1' => '[@nom_site_spip@] Proposto : @titre@',
	'info_propose_2' => 'Artigos propostos
----------------',
	'info_propose_3' => 'O artigo "@titre@" é proposto para publicação.',
	'info_propose_4' => 'Está convidado a vir consultá-lo e a dar a sua opinião',
	'info_propose_5' => 'no fórum que lhe está ligado. Está disponível no endereço:',
	'info_publie_01' => 'O artigo "@titre@" foi validado por @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICADO : @titre@',
	'info_publie_2' => 'Artigo publicado
--------------',
	'info_rechercher' => 'Procurar',
	'info_rechercher_02' => 'Procurar :',
	'info_remplacer_vignette' => 'Substituir a miniatura por defeito por um logotipo personalizado :',
	'info_rubriques_nb' => '@nb@ rubricas',
	'info_rubriques_un' => '1 rubrica',
	'info_sans_titre_2' => 'sem título',
	'info_selectionner_fichier' => 'Pode seleccionar um ficheiro da pasta @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar um ficheiro :',
	'info_sites_nb' => '@nb@ sítios',
	'info_sites_un' => '1 sítio',
	'info_supprimer_vignette' => 'suprimir a miniatura',
	'info_symbole_bleu' => 'O símbolo <b>azul</b> indica um<b>memorando </b>: isto é uma mensagem para o seu uso pessoal.',
	'info_symbole_jaune' => 'O símbolo<b>amarelo</b> indica um <b>anúncio a todos os redactores</b> : modificável por todos os administradores, e visível por todos os redactores.',
	'info_symbole_vert' => 'O símbolo<b>verde</b> indica as <b>mensagens trocadas com outros utilizadores</b> do sítio.',
	'info_telecharger_nouveau_logo' => 'Telecarregar um novo logotipo :',
	'info_telecharger_ordinateur' => 'Telecarregar do seu computador :',
	'info_tous_resultats_enregistres' => '[todos os  resultados estão registados]',
	'info_tout_afficher' => 'Exibir tudo',
	'info_travaux_texte' => 'Este sítio ainda não está configurado. Volte mais tarde...',
	'info_travaux_titre' => 'Sítio em construção',
	'info_trop_resultat' => 'Demasiado resultados para "@cherche_mot@". Por favor afine a pesquisa.',
	'info_utilisation_messagerie_interne' => 'Você utiliza o correio interno deste sítio.',
	'info_valider_lien' => 'validar esta ligação',
	'info_verifier_image' => ', Por favor verifique se as suas imagens foram transferidas correctamente.',
	'info_vignette_defaut' => 'Miniatura por defeito',
	'info_vignette_personnalisee' => 'Miniatura personalizada',
	'info_visite' => 'visita :',
	'info_vos_rendez_vous' => 'Os seus futuros encontros',
	'infos_vos_pense_bete' => 'Os seus memorandos',

	// L
	'label_ajout_id_rapide' => 'Adição rápida',
	'label_poids_fichier' => 'Dimensões',
	'lien_afficher_icones_seuls' => 'Exibir apenas os ícones',
	'lien_afficher_texte_icones' => 'Exibir ícones e o texto',
	'lien_afficher_texte_seul' => 'Exibir apenas o texto',
	'lien_liberer' => 'desbloquear',
	'lien_liberer_tous' => 'desbloquear estes artigos',
	'lien_nouvea_pense_bete' => 'NOVO MEMORANDO',
	'lien_nouveau_message' => 'NOVA MENSAGEM',
	'lien_nouvelle_annonce' => 'NOVO ANÚNCIO',
	'lien_petitions' => 'PETIÇÃO',
	'lien_popularite' => 'popularidade : @popularite@%',
	'lien_racine_site' => 'RAIZ DO SÍTIO',
	'lien_reessayer' => 'tentar de novo',
	'lien_repondre_message' => 'Responder a esta mensagem',
	'lien_supprimer' => 'eliminar',
	'lien_tout_afficher' => 'Exibir tudo',
	'lien_visite_site' => 'visitar este sítio',
	'lien_visites' => '@visites@ visitas',
	'lien_voir_auteur' => 'Ver este autor',
	'ligne' => 'Linha',
	'login' => 'Ligação',
	'login_acces_prive' => 'acesso ao espaço privado',
	'login_autre_identifiant' => 'ligar-se sob um outro identificador',
	'login_cookie_accepte' => 'Por favor configure o seu navegador para que os aceite (pelo menos para este sítio).',
	'login_cookie_oblige' => 'Para se identificar de maneira segura neste sítio, deve aceitar os cookies.',
	'login_deconnexion_ok' => 'Ligação terminada.',
	'login_erreur_pass' => 'Erro de palavra-passe',
	'login_espace_prive' => 'área privada',
	'login_identifiant_inconnu' => 'O identificador « @login@ » é desconhecido.',
	'login_login' => 'Login :',
	'login_login2' => 'Login ou endereço de e-mail :',
	'login_login_pass_incorrect' => '(Login ou palavra-passe incorrecta.)',
	'login_motpasseoublie' => 'palavra - passe esquecida ?',
	'login_non_securise' => 'Atenção, este formulário não é seguro.
 Se não quiser que a sua palavra-passe seja
 interceptada na rede, por favor active Javascript
 no seu navegador e',
	'login_nouvelle_tentative' => 'Nova tentativa',
	'login_par_ici' => 'Você está registado... por aqui....',
	'login_pass2' => 'Palavra-passe :',
	'login_preferez_refuser' => '<b>Se prefere recusar os cookies</b>, um outro método de ligação (menos seguro) está à sua disposição',
	'login_recharger' => 'carregar de novo esta página ',
	'login_rester_identifie' => 'Permanecer identificado durante alguns dias ', # MODIF
	'login_retour_public' => 'Regresso ao sítio público',
	'login_retour_site' => 'Regresso ao sítio público',
	'login_retoursitepublic' => 'Regresso ao sítio público',
	'login_securise' => 'Login seguro',
	'login_sinscrire' => 'inscrever-se',
	'login_test_navigateur' => 'teste navegação/nova ligação',
	'login_verifiez_navigateur' => '(Verifique, porém, que o seu navegador não memorizou a sua palavra-passe...)',

	// M
	'masquer_colonne' => 'Ocultar esta coluna',
	'masquer_trad' => 'ocultar as traduções',
	'module_fichiers_langues' => 'Ficheiros de idioma',

	// N
	'navigateur_pas_redirige' => 'Se o seu navegador não está redireccionado, clique aqui para continuar.',
	'numero' => 'Número',

	// O
	'occurence' => 'Ocorrência',
	'onglet_affacer_base' => 'Apagar a base de dados',
	'onglet_auteur' => 'O autor',
	'onglet_contenu_site' => 'Conteúdo do sítio',
	'onglet_evolution_visite_mod' => 'Evolução',
	'onglet_fonctions_avances' => 'Funções avançadas',
	'onglet_informations_personnelles' => 'Informações pessoais',
	'onglet_interactivite' => 'Interactividade',
	'onglet_messagerie' => 'Correio',
	'onglet_repartition_rubrique' => 'Distribuição das rubricas',
	'onglet_save_restaur_base' => 'Guardar uma cópia/restaurar a base',
	'onglet_vider_cache' => 'Esvaziar a cache',

	// P
	'pass_choix_pass' => 'Por favor escolha a sua nova palavra-passe',
	'pass_erreur' => 'Erro',
	'pass_erreur_acces_refuse' => '<b>Erro :</b> já não tem acesso a este sítio.',
	'pass_erreur_code_inconnu' => '<b>Erro :</b> este código não corresponde a nenhum dos visitantes com acesso a este sítio.',
	'pass_erreur_non_enregistre' => '<b>Erro :</b> o endereço <tt>@email_oubli@</tt> não está registado neste sítio. ',
	'pass_erreur_non_valide' => '<b>Erro :</b> este email <tt>@email_oubli@</tt> não é válido !  ',
	'pass_erreur_probleme_technique' => '<b>Erro :</b> por causa de um problema técnico, o email não pôde ser enviado.',
	'pass_espace_prive_bla' => 'O espaço privado deste sítio está aberto aos
 visitantes, após inscrição. Uma vez registado poderá consultar os artigos em curso de redacção,
propor artigos e participar em todos os fóruns.',
	'pass_forum_bla' => 'Pediu para intervir num fórum
 reservado aos visitadores registados.',
	'pass_indiquez_cidessous' => 'Indique abaixo o endereço email sob o qual se registou. Receberá
 um mail que indicará o procedimento a seguir para
        recuperar o seu acesso.',
	'pass_mail_passcookie' => '(esta é uma mensagem automática)
Para recuperar o seu acesso ao sítio
@nom_site_spip@ (@adresse_site@)

Por favor vá ao seguinte endereço :

    @sendcookie@

Poderá então introduzir uma nova palavra-passe e reconectar-se ao sítio.
',
	'pass_mot_oublie' => 'Palavra-passe esquecida',
	'pass_nouveau_enregistre' => 'A sua nova palavra-passe foi registada',
	'pass_nouveau_pass' => 'Nova palavra-passe',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Palavra-passe esquecida',
	'pass_procedure_changer' => 'Para alterar a sua palavra-passe, temos primeiro de verificar a sua identidade. Por favor escreva o endereço e-mail associado a esta conta.', # MODIF
	'pass_quitter_fenetre' => 'Fechar esta janela',
	'pass_rappel_login' => 'Recorde : o seu identificador (login) é « @login@ ».',
	'pass_recevoir_mail' => 'Vai receber um email que indica como recuperar o seu acesso ao sítio.', # MODIF
	'pass_retour_public' => 'Regresso ao sítio público',
	'pass_rien_a_faire_ici' => 'Nada a fazer aqui.',
	'pass_vousinscrire' => 'Inscrever-se neste sítio',
	'precedent' => 'anterior',
	'previsualisation' => 'Visualização',
	'previsualiser' => 'Pré-visualizar',

	// R
	'retour' => 'Retroceder',

	// S
	'spip_conforme_dtd' => 'SPIP considera esta página em conforme com o seu DOCTYPE :',
	'squelette' => 'modelo',
	'squelette_inclus_ligne' => 'modelo incluído, linha',
	'squelette_ligne' => 'modelo, linha',
	'stats_visites_et_popularite' => '@visites@ visitas ; popularidade : @popularite@',
	'suivant' => 'seguinte',

	// T
	'taille_go' => '@taille@ Gb',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => ' @taille@ bytes',
	'texte_actualite_site_1' => 'Quando estiver familiarizado(a) com a interface, poderá clicar em «',
	'texte_actualite_site_2' => 'interface completa',
	'texte_actualite_site_3' => '» para abrir mais possibilidades.',
	'texte_creation_automatique_vignette' => 'A criação automática de miniaturas de pré-visualização está activada neste sítio. Se instalar a partir deste formulário imagens de formato(s) @gd_formats@, serão acompanhadas de uma miniatura de um tamanho máximo de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Os documentos seguintes estão associados ao artigo,
  mas não foram directamente
 inseridos nele. Conforme a paginação do sítio público,
  poderão aparecer sob forma de documentos anexados.',
	'texte_erreur_mise_niveau_base' => 'Erro de base de dados por ocasião do nivelamento.
   A imagem <b>@fichier@</b> não passou (artigo @id_article@).
  Note bem esta referência, volte a tentar o nivelamento, e verifique se as imagens aparecem sempre nos artigos.',
	'texte_erreur_visiteur' => 'Tentou aceder à área privada usando um login não autorizado.',
	'texte_inc_auth_1' => 'Você está identificado sob o
   login <b>@auth_login@</b>, mas este já/ não existe na base de dados.
 Tente',
	'texte_inc_auth_2' => 'refazer a ligação',
	'texte_inc_auth_3' => ', depois de eventualmente ter fechado e
 voltado a abrir o seu navegador.',
	'texte_inc_config' => 'As modificações efectuadas nestas páginas influenciam muito o
 funcionamento do seu sítio. Recomendamos que não intervenha enquanto não estiver familiarizado com o funcionamento do sistema SPIP. <br /><br /><b> Em
 geral, é fortemente recomendado
 deixar a responsabilidade dessas páginas ao webmaster principal do seu sítio. <b>',
	'texte_inc_meta_1' => 'O sistema encontrou um erro durante a escrita do arquivo <code>@fichier@</code>. Como administrador do sítio, por favor,',
	'texte_inc_meta_2' => 'verificar as permissões de escrita',
	'texte_inc_meta_3' => 'no directório <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'em curso de redacção',
	'texte_statut_poubelle' => 'para o caixote de lixo',
	'texte_statut_propose_evaluation' => 'proposto para avaliação',
	'texte_statut_publie' => 'publicado online',
	'texte_statut_refuse' => 'recusado',
	'titre_ajouter_mot_cle' => 'ACRESCENTAR UMA PALAVRA-CHAVE',
	'titre_cadre_raccourcis' => 'ATALHOS :',
	'titre_changer_couleur_interface' => 'Mudar a cor da interface',
	'titre_image_admin_article' => 'Pode administrar este artigo',
	'titre_image_administrateur' => 'Administrador',
	'titre_image_aide' => 'Ajuda sobre este elemento',
	'titre_image_auteur_supprime' => 'Autor eliminado',
	'titre_image_redacteur' => 'Redactor sem acesso',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_selecteur' => 'Exibir a lista',
	'titre_image_visiteur' => 'Visitante',
	'titre_joindre_document' => 'ANEXAR UM DOCUMENTO',
	'titre_mots_cles' => 'PALAVRAS-CHAVE',
	'titre_probleme_technique' => 'Atenção : um problema técnico (servidor SQL) impede o acesso a esta parte do sítio. Obrigado pela sua compreensão.',
	'titre_publier_document' => 'PUBLICAR UM DOCUMENTO NESTA RUBRICA',
	'titre_signatures_attente' => 'Assinaturas aguardando validação',
	'titre_signatures_confirmees' => 'Assinaturas confirmadas',
	'titre_statistiques' => 'Estatísticas do sítio',
	'titre_titre_document' => 'Título do documento :',
	'todo' => 'a caminho',
	'trad_reference' => '(referência para as traduções)',

	// Z
	'zbug_balise_b_aval' => ': tag B colocada demasiado tarde no laço infinito',
	'zbug_balise_inexistante' => 'Tag @balise@ mal declarada para @from@',
	'zbug_balise_sans_argument' => 'Argumento em falta na tag @balise@',
	'zbug_boucle' => 'laço infinito',
	'zbug_boucle_recursive_undef' => 'laço recursivo não definido @nom@',
	'zbug_calcul' => 'cálculo',
	'zbug_champ_hors_boucle' => 'Campo @champ@ fora do laço infinito',
	'zbug_champ_hors_motif' => 'Campo @champ@ fora de contexto @motif@',
	'zbug_code' => 'código',
	'zbug_critere_inconnu' => 'critério desconhecido @critere@ ',
	'zbug_distant_interdit' => 'Dados externos interditos',
	'zbug_doublon_table_sans_cle_primaire' => 'Entradas duplas numa tabela que não tem uma chave primária simples',
	'zbug_doublon_table_sans_index' => 'Entradas duplas numa tabela sem índice',
	'zbug_erreur_boucle_double' => 'laço @id@: Dupla definição ',
	'zbug_erreur_boucle_fermant' => 'laço @id@: tag final em falta   ',
	'zbug_erreur_boucle_syntaxe' => 'Laço com sintaxe incorrecta @id@',
	'zbug_erreur_compilation' => 'Erro de compilação',
	'zbug_erreur_execution_page' => 'erro de execução da página',
	'zbug_erreur_filtre' => 'Erro : filtro indefinido @filtre@ ',
	'zbug_erreur_meme_parent' => '{meme_parent} aplica-se exclusivamente aos laços (FORUMS) ou (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Erro(s) no modelo',
	'zbug_hors_compilation' => 'Não compilado',
	'zbug_info_erreur_squelette' => 'Erro no sítio',
	'zbug_inversion_ordre_inexistant' => 'inversão de uma ordem inexistente',
	'zbug_pagination_sans_critere' => '#PAGINAÇÃO sem critério {paginação} ou usada num laço recursivo',
	'zbug_parametres_inclus_incorrects' => 'Parâmetros de inclusão incorrectos: @param@',
	'zbug_profile' => 'Cálculo de tempo : @time@',
	'zbug_resultat' => 'resultado',
	'zbug_serveur_indefini' => 'Sevidor SQL não definido',
	'zbug_statistiques' => 'Estatísticas das consulta SQL classificadas por duração',
	'zbug_table_inconnue' => 'Tabela SQL «@table@» desconhecida',
	'zxml_connus_attributs' => 'attributos conhecidos',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atributo desconhecido',
	'zxml_inconnu_balise' => 'tag desconhecida',
	'zxml_inconnu_entite' => 'entidade desconhecida',
	'zxml_inconnu_id' => 'ID desconhecido',
	'zxml_mais_de' => 'mas de',
	'zxml_non_conforme' => 'não está de acordo com o princípio',
	'zxml_non_fils' => 'não é um filho de ',
	'zxml_nonvide_balise' => 'a tag não está vazia',
	'zxml_obligatoire_attribut' => 'atributo obrigatório está em falta',
	'zxml_succession_fils_incorrecte' => 'sucessão de filhos incorrecta',
	'zxml_survoler' => 'para visualizar os correctos, mover o rato por cima',
	'zxml_valeur_attribut' => 'valor do atributo',
	'zxml_vide_balise' => 'tag vazia',
	'zxml_vu' => 'visualizado antes'
);
